@@ -4,11 +4,11 @@ import (
 	"fmt"
 	"testing"
 
-	configv1 "github.com/openshift/api/config/v1"
 	olm "github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
 	"github.com/operator-framework/operator-marketplace/pkg/apis"
-	marketplace "github.com/operator-framework/operator-marketplace/pkg/apis/operators/v1"
-
+	"github.com/operator-framework/operator-marketplace/pkg/apis/operators/v1"
+	"github.com/operator-framework/operator-marketplace/pkg/apis/operators/v2"
+	"github.com/operator-framework/operator-marketplace/test/helpers"
 	"github.com/operator-framework/operator-marketplace/test/testgroups"
 	"github.com/operator-framework/operator-sdk/pkg/test"
 
@@ -24,27 +24,30 @@ func TestMarketplace(t *testing.T) {
 	initTestingFramework(t)
 
 	// Run Test Groups
-	t.Run("cluster-operator-status-test-group", testgroups.ClusterOperatorTestGroup)
-	t.Run("operator-source-test-group", testgroups.OperatorSourceTestGroup)
+	if isConfigAPIPresent, _ := helpers.EnsureConfigAPIIsAvailable(); isConfigAPIPresent == true {
+		t.Run("cluster-operator-status-test-group", testgroups.ClusterOperatorTestGroup)
+	}
+	t.Run("opsrc-csc-test-group", testgroups.OpSrcCscTestGroup)
 	t.Run("no-setup-test-group", testgroups.NoSetupTestGroup)
+	t.Run("migration-test-group", testgroups.MigrationTestGroup)
 }
 
 // initTestingFramework adds the marketplace OperatorSource and CatalogSourceConfig types as well as the
 // olm CatalogSource type to the framework scheme.
 func initTestingFramework(t *testing.T) {
 	// Add marketplace types to test framework scheme.
-	operatorSource := &marketplace.OperatorSource{
+	operatorSource := &v1.OperatorSource{
 		TypeMeta: metav1.TypeMeta{
-			Kind: marketplace.OperatorSourceKind,
+			Kind: v1.OperatorSourceKind,
 			APIVersion: fmt.Sprintf("%s/%s",
-				marketplace.SchemeGroupVersion.Group, marketplace.SchemeGroupVersion.Version),
+				v1.SchemeGroupVersion.Group, v1.SchemeGroupVersion.Version),
 		},
 	}
-	catalogSourceConfig := &marketplace.CatalogSourceConfig{
+	catalogSourceConfig := &v2.CatalogSourceConfig{
 		TypeMeta: metav1.TypeMeta{
-			Kind: marketplace.CatalogSourceConfigKind,
+			Kind: v2.CatalogSourceConfigKind,
 			APIVersion: fmt.Sprintf("%s/%s",
-				marketplace.SchemeGroupVersion.Group, marketplace.SchemeGroupVersion.Version),
+				v2.SchemeGroupVersion.Group, v2.SchemeGroupVersion.Version),
 		},
 	}
 	err := test.AddToFrameworkScheme(apis.AddToScheme, operatorSource)
@@ -66,16 +69,11 @@ func initTestingFramework(t *testing.T) {
 	if err != nil {
 		t.Fatalf("failed to add CatalogSource custom resource scheme to framework: %v", err)
 	}
-	// Add (configv1) ClusterOperator to framework scheme
-	clusterOperator := &configv1.ClusterOperator{
-		TypeMeta: metav1.TypeMeta{
-			Kind: "ClusterOperator",
-			APIVersion: fmt.Sprintf("%s/%s",
-				configv1.SchemeGroupVersion.Group, configv1.SchemeGroupVersion.Version),
-		},
-	}
-	err = test.AddToFrameworkScheme(configv1.Install, clusterOperator)
+
+	_, err = helpers.EnsureConfigAPIIsAvailable()
 	if err != nil {
-		t.Fatalf("failed to add ClusterOperator custom resource scheme to framework: %v", err)
+		t.Logf("failed to add OpenShift config custom resource scheme to framework: %v. config tests will not run.",
+			err)
 	}
+
 }
